@@ -1,14 +1,15 @@
 package Net::DNS::Resolver::UNIX;
 #
-# $Id: UNIX.pm,v 1.1 2003/06/11 09:56:13 ctriv Exp $
+# $Id: UNIX.pm,v 1.2 2003/08/26 23:58:10 ctriv Exp $
 #
 
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS::Resolver::Base ();
 
-@ISA = qw(Net::DNS::Resolver::Base);
+@ISA     = qw(Net::DNS::Resolver::Base);
+$VERSION = (qw$Revision: 1.2 $)[1];
 
 my $resolv_conf = '/etc/resolv.conf';
 my $dotfile     = '.resolv.conf';
@@ -20,11 +21,11 @@ push(@config_path, '.');
 sub init {
 	my ($class) = @_;
 	
-	$class->read_config_file($resolv_conf) if -f $resolv_conf && -r $resolv_conf; 
+	$class->read_config_file($resolv_conf) if -f $resolv_conf && -r _; 
 	
 	foreach my $dir (@config_path) {
 		my $file = "$dir/$dotfile";
-		$class->read_config_file($file) if -f $file && -r $file && -o $file;
+		$class->read_config_file($file) if -f $file && -r _ && -o _;
 	}
 	
 	$class->read_env;
